/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.spi.client.container;

import org.jboss.arquillian.container.spi.client.protocol.ProtocolDescription;
import org.jboss.arquillian.container.spi.client.protocol.metadata.ProtocolMetaData;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.descriptor.api.Descriptor;

/**
 * DeployableContainer
 *
 * @author <a href="mailto:aslak@conduct.no">Aslak Knutsen</a>
 * @version $Revision: $
 */
public interface DeployableContainer<T extends ContainerConfiguration>
{
   // ControllableContainer
   Class<T> getConfigurationClass();
   
   void setup(T configuration);
   
   void start() throws LifecycleException;

   void stop() throws LifecycleException;

   // DeployableContainer
   ProtocolDescription getDefaultProtocol();

   ProtocolMetaData deploy(Archive<?> archive) throws DeploymentException;
   
   void undeploy(Archive<?> archive) throws DeploymentException;

   // Admin ?
   void deploy(Descriptor descriptor) throws DeploymentException;
   
   void undeploy(Descriptor descriptor) throws DeploymentException;

}